package org.xbib.interlibrary.db.zfl.postgresql;

import java.io.IOException;
import java.util.List;
import org.xbib.interlibrary.api.ApplicationModule;
import org.xbib.interlibrary.api.config.ConfigManager;
import org.xbib.interlibrary.api.event.OrderEventManager;
import org.xbib.interlibrary.api.order.OrderManager;
import org.xbib.interlibrary.api.order.statistics.StatisticsManager;
import org.xbib.interlibrary.api.route.RouteManager;
import org.xbib.interlibrary.api.template.TemplateManager;
import org.xbib.interlibrary.http.HttpHelper;
import org.xbib.interlibrary.db.AbstractDatabaseModule;

public class ZflDatabaseModule extends AbstractDatabaseModule {

    private HttpHelper httpHelper;

    public ZflDatabaseModule() {
        super();
    }

    @Override
    public String getName() {
        return "zfl";
    }

    @Override
    public List<Class<? extends ApplicationModule>> dependsOn() {
        return null;
    }

    @Override
    protected String getFlavor() {
        return "postgresql";
    }

    @Override
    protected void beforeOpen() throws IOException {
        this.httpHelper = new HttpHelper();
        httpHelper.open(getInterlibrary().getSettings().getAsSettings("http"));
    }

    @Override
    protected void afterOpen() throws IOException {
    }

    @Override
    protected ConfigManager createConfigManager() throws IOException {
        return new ZflConfigManager(this);
    }

    @Override
    protected OrderEventManager createEventManager() throws IOException {
        return new ZflEventManager(this);
    }

    @Override
    protected OrderManager createOrderManager() throws IOException {
        return new ZflOrderManager(this);
    }

    @Override
    protected RouteManager createRouteManager() throws IOException {
        return new ZflRouteManager(this, httpHelper);
    }

    @Override
    protected StatisticsManager createStatisticsManager() throws IOException {
        return new ZflStatisticsManager(this);
    }

    @Override
    protected TemplateManager createTemplateManager() throws IOException {
        return new ZflTemplateManager(this);
    }

    /**
     * Parse "tilde format"
     * <p>
     * ~465#NRW OHNESIGNATUR~61#NRW OHNESIGNATUR~HAG4#NRW OHNESIGNATUR~DÃŒ62#??? OHNESIGNATUR~DM13#NRW OHNESIGNATUR~1393#NRW OHNESIGNATUR~1044#NRW OHNESIGNATUR~386#NRW OHNESIGNATUR~6#NRW OHNESIGNATUR~294#NRW OHNESIGNATUR~5#NRW OHNESIGNATUR~929#NRW OHNESIGNATUR
     *
     * @param source the zf8quelle field from ZFL
     * @return cleaned source
     */
    @Override
    public String parseSource(String source) {
        if (source == null) {
            return null;
        }
        for (String segment : source.split("~")) {
            int pos = segment.indexOf('#');
            String region = pos > 0 ? segment.substring(pos + 1) : "";
            if (region.contains("NRW")) {
                return "HBZ";
            }
        }
        return source;
    }

    @Override
    public void run() {
    }
}
