select /*+ FIRST_ROWS(10) */
    row_number() over (order by m.zf1bestellid desc) as "pos",
    to_timestamp(to_char(i.zf6date,'DD.MM.YYYY') || ' ' || i.zf6uhr, 'DD.MM.YYYY HH24::MI::SS') as "ordertime",
    to_timestamp(to_char(s.zf6date,'DD.MM.YYYY') || ' ' || s.zf6uhr, 'DD.MM.YYYY HH24::MI::SS') as "lastactivitytime",
    case when trim(s.zf6vorgang) = 'Shipped' then to_timestamp(to_char(s.zf6date,'DD.MM.YYYY') || ' ' || s.zf6uhr, 'DD.MM.YYYY HH24::MI::SS') else null end as "supplytime",
    m.zf1bestellid as "ordernumber",
    decode(m.zf1tan,
       'DUMMY', m.zf1bestellid,
       m.zf1tan) as "transactionid",
    trim(m.zf1pfl2afl) as "externaltransactionnumber",
    'ZFL' as "ordersystem",
    decode(m.zf1bstype2,
      'C', 'COPY',
      'L', 'LOAN',
      'F', 'FORM',
      'V', 'RESERVATION',
      m.zf1bstype2) as "circulation",
    trim(s.zf6vorgang) as "status",
    trim(s.zf6local) as "substatus",
    decode(sup.zf10isil,
      'SWB', 'EXTERNAL',
      'GBV', 'EXTERNAL',
      'KOBV', 'EXTERNAL',
      'HEBIS', 'EXTERNAL',
      'BVB', 'EXTERNAL',
      'DE-576', 'EXTERNAL',
      'DE-601', 'EXTERNAL',
      'DE-602', 'EXTERNAL',
      'DE-603', 'EXTERNAL',
      'DE-604', 'EXTERNAL',
      'DE-38', 'INTERNAL',
      'DE-38M', 'INTERNAL',
      'DE-82', 'INTERNAL',
      'DE-Kn41', 'INTERNAL',
      'DE-Bo133', 'INTERNAL',
      'INTERNAL') as "deliveryscope",
    'UNDEFINED' as "deliverystyle",
    decode(req.zf10isil,
      'SWB', 'EXTERNAL',
      'GBV', 'EXTERNAL',
      'KOBV', 'EXTERNAL',
      'HEBIS', 'EXTERNAL',
      'BVB', 'EXTERNAL',
      'DE-576', 'EXTERNAL',
      'DE-601', 'EXTERNAL',
      'DE-602', 'EXTERNAL',
      'DE-603', 'EXTERNAL',
      'DE-604', 'EXTERNAL',
      'DE-38', 'INTERNAL',
      'DE-38M', 'INTERNAL',
      'DE-82', 'INTERNAL',
      'DE-Kn41', 'INTERNAL',
      'DE-Bo133', 'INTERNAL',
      'INTERNAL') as "notifymethod",
    'UNDEFINED' as "notifystyle",
    decode(req.zf10isil,
      'SWB', 'DE-576',
      'GBV', 'DE-601',
      'KOBV', 'DE-602',
      'HEBIS', 'DE-603',
      'BVB', 'DE-604',
      'hbz', 'DE-605',
      req.zf10isil) as "requesterisil",
    u.zf2bnr as "clientid",
    u.zf2vname || ' ' || u.zf2name as "clientname",
    t.zf8bemerkung as "clientcomment",
    case when instr(t.zf8info, 'Andere Ausgabe:: ja') > 0 then 'ja' else 'nein' end as "otheredition",
    case when instr(t.zf8info, 'Vormerkung:: ja') > 0 then 'ja' else 'nein' end as "reservation",
    t.zf8maxkostenkopie as "maxcost",
    e1.message as "pickuplocation",
    e2.message as "clientemail",
    e3.message as "externalrequester",
    e4.message as "pickupcode",
    decode(sup.zf10isil,
      'SWB', 'DE-576',
      'GBV', 'DE-601',
      'KOBV', 'DE-602',
      'HEBIS', 'DE-603',
      'BVB', 'DE-604',
      'hbz', 'DE-605',
      sup.zf10isil) as "supplierisil",
    decode(e5.time,
      NULL, -1,
    sysdate - cast(e5.time as date)) as "deliveryage",
    t.zf8pdfseiten as "pages",
    trim(decode(t.zf8aufsatzautor,
       NULL, t.ZF8VERFASSER,
      t.zf8aufsatzautor)) as "author",
    trim(t.zf8atitel) as "title",
    trim(t.zf8titel) as "intitle",
    to_char(t.zf8jahr) as "year",
    t.zf8band as "volume",
    t.zf8heft as "issue",
    t.zf8seiten as "pagination",
    t.zf8verlag as "publisher",
    trim(t.zf8eort) as "publisherplace",
    decode(t.zf8isbn, NULL, '', trim(t.zf8isbn)) as "isbn",
    decode(t.zf8issn, NULL, '', trim(t.zf8issn)) as "issn",
    NVL(SUBSTR(t.zf8quelle, 0, INSTR(t.zf8quelle, '$') - 1), t.zf8quelle) as "source",
    t.zf8titelid as "sourceid",
    e6.message as "doi"
from zf1medien m
    inner join zf8titel t on m.zf1bestellid = t.zf8bestellid
    inner join zf6status i on m.zf1bestellid = i.zf6bestellid and i.zf6lfd = 1
    inner join zf6status s on m.zf1bestellid = s.zf6bestellid and m.zf1lfd = s.zf6lfd
    inner join zf2benutzer u on m.zf1bnr = u.zf2bnr and m.zf1sigelnb_id = u.zf2sigelnb_id
    left outer join zf7leitweg zl on s.zf6bestellid = zl.zf7bestellid and s.zf6prio = zl.zf7prio
    left outer join zf10bibl sup on zl.zf7sigel_id = sup.zf10id
    left outer join zf10bibl req on m.zf1sigelnb_id = req.zf10id
    left outer join event e1 on m.zf1bestellid = e1.ordernumber and e1.type = 'requestform' and e1.code = 'pickuplocation'
    left outer join event e2 on m.zf1bestellid = e2.ordernumber and e2.type = 'requestform' and e2.code = 'requesteremail'
    left outer join event e3 on m.zf1bestellid = e3.ordernumber and e3.type = 'requestform' and e3.code = 'externalrequester'
    left outer join event e4 on m.zf1bestellid = e4.ordernumber and e4.type = 'requestform' and e4.code = 'pickupcode'
    left outer join event e5 on m.zf1bestellid = e5.ordernumber and e5.type = 'transaction' and e5.code = 'transaction-success'
    left outer join event e6 on m.zf1bestellid = e6.ordernumber and e6.type = 'requestform' and e6.code = 'doi'
